==> Weblate-2.18.tar.bz2: Weblate-2.18/weblate/trans/models/comment.py <==
# -*- coding: utf-8 -*-
#
# Copyright © 2012 - 2017 Michal Čihař <michal@cihar.com>
#
# This file is part of Weblate <https://weblate.org/>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#

from __future__ import unicode_literals

from django.contrib.auth.models import User
from django.db import models
from django.utils.encoding import python_2_unicode_compatible

from weblate.lang.models import Language
from weblate.trans.mixins import UserDisplayMixin
from weblate.trans.models.change import Change
from weblate.accounts.notifications import notify_new_comment


class CommentManager(models.Manager):
    # pylint: disable=W0232

    def add(self, unit, user, lang, text):
        """Add comment to this unit."""
        new_comment = self.create(
            user=user,
            content_hash=unit.content_hash,
            project=unit.translation.subproject.project,
            comment=text,
            language=lang
        )
        Change.objects.create(
            unit=unit,
            action=Change.ACTION_COMMENT,
            translation=unit.translation,
            user=user,
            author=user
        )

        # Notify subscribed users
        notify_new_comment(
            unit,
            new_comment,
            user,
            unit.translation.subproject.report_source_bugs
        )


@python_2_unicode_compatible
class Comment(models.Model, UserDisplayMixin):
    content_hash = models.BigIntegerField(db_index=True)
    comment = models.TextField()
    user = models.ForeignKey(
        User, null=True, blank=True, on_delete=models.deletion.CASCADE
    )
    project = models.ForeignKey(
        'Project', on_delete=models.deletion.CASCADE
    )
    language = models.ForeignKey(
        Language, null=True, blank=True, on_delete=models.deletion.CASCADE
    )
    timestamp = models.DateTimeField(auto_now_add=True, db_index=True)

    objects = CommentManager()

    class Meta(object):
        ordering = ['timestamp']
        app_label = 'trans'

    def __str__(self):
        return 'comment for {0} by {1}'.format(
            self.content_hash,
            self.user.username if self.user else 'unknown',
        )

==> Weblate-3.5.tar.bz2: Weblate-3.5/weblate/trans/models/comment.py <==
# -*- coding: utf-8 -*-
#
# Copyright © 2012 - 2019 Michal Čihař <michal@cihar.com>
#
# This file is part of Weblate <https://weblate.org/>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#

from __future__ import unicode_literals

from django.conf import settings
from django.db import models
from django.utils.encoding import python_2_unicode_compatible

from weblate.trans.mixins import UserDisplayMixin
from weblate.trans.models.change import Change
from weblate.utils.unitdata import UnitData


class CommentManager(models.Manager):
    # pylint: disable=no-init

    def add(self, unit, user, lang, text):
        """Add comment to this unit."""
        new_comment = self.create(
            user=user,
            content_hash=unit.content_hash,
            project=unit.translation.component.project,
            comment=text,
            language=lang
        )
        Change.objects.create(
            unit=unit,
            action=Change.ACTION_COMMENT,
            user=user,
            author=user
        )

        # Notify subscribed users
        from weblate.accounts.notifications import notify_new_comment
        notify_new_comment(
            unit,
            new_comment,
            user,
            unit.translation.component.report_source_bugs
        )

    def copy(self, project):
        """Copy comments to new project

        This is used on moving component to other project and ensures nothing
        is lost. We don't actually look where the comment belongs as it
        would make the operation really expensive and it should be done in the
        cleanup cron job.
        """
        for comment in self.all():
            Comment.objects.create(
                project=project,
                comment=comment.comment,
                content_hash=comment.content_hash,
                user=comment.user,
                language=comment.language,
            )


@python_2_unicode_compatible
class Comment(UnitData, UserDisplayMixin):
    comment = models.TextField()
    user = models.ForeignKey(
        settings.AUTH_USER_MODEL, null=True, blank=True,
        on_delete=models.deletion.CASCADE
    )
    timestamp = models.DateTimeField(auto_now_add=True, db_index=True)

    objects = CommentManager()

    class Meta(object):
        ordering = ['timestamp']
        app_label = 'trans'
        index_together = [
            ('project', 'language', 'content_hash'),
        ]

    def __str__(self):
        return 'comment for {0} by {1}'.format(
            self.content_hash,
            self.user.username if self.user else 'unknown',
        )
